==> mingw-w64-arrow-14.0.2-1.src.tar.zst: apache-arrow-14.0.2/java/vector/src/main/java/org/apache/arrow/vector/BaseIntVector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.arrow.vector;

/**
 * Interface for all int type vectors.
 */
public interface BaseIntVector extends FieldVector {

  /**
   * Sets the value at index, note this value may need to be truncated.
   * Note this is safe version (i.e. call setSafe(int, ...) method in vector)
   */
  void setWithPossibleTruncate(int index, long value);

  /**
   * Sets the value at index, note this value may need to be truncated.
   * Note this is unsafe version (i.e. call set(int, ...) method in vector)
   */
  void setUnsafeWithPossibleTruncate(int index, long value);

  /**
   * Gets the value at index.
   * This value may have been extended to long and will throw {@link NullPointerException}
   * if the value is null. Note null check could be turned off via {@link NullCheckingForGet}.
   */
  long getValueAsLong(int index);
}

==> mingw-w64-arrow-18.1.0-3.src.tar.zst: apache-arrow-18.1.0/java/vector/src/main/java/org/apache/arrow/vector/BaseIntVector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.arrow.vector;

/** Interface for all int type vectors. */
public interface BaseIntVector extends FieldVector {

  /**
   * Sets the value at index, note this value may need to be truncated. Note this is safe version
   * (i.e. call setSafe(int, ...) method in vector)
   */
  void setWithPossibleTruncate(int index, long value);

  /**
   * Sets the value at index, note this value may need to be truncated. Note this is unsafe version
   * (i.e. call set(int, ...) method in vector)
   */
  void setUnsafeWithPossibleTruncate(int index, long value);

  /**
   * Gets the value at index. This value may have been extended to long and will throw {@link
   * NullPointerException} if the value is null. Note null check could be turned off via {@link
   * NullCheckingForGet}.
   */
  long getValueAsLong(int index);
}
